Documentation
¶
Overview ¶
To avoid circular dependencies, interfaces contains the core implementation of the job interfaces
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JobImpl ¶
type JobImpl interface {
// Name returns the name of the job
Name() string
// As jobs often deal with sensitive data such as secrets, the Fields method returns
// a map of fields that can be stored in the database
Fields() map[string]any
// Validate validates and sets up state if needed
Validate(state jobstate.State) error
// Exec executes the job returning an output if any
Exec(l *zap.Logger, state jobstate.State, progstate jobstate.ProgressState) (*types.Output, error)
// Expiry returns when the job will expire (if any), setting this to nil will make the job not expire
Expiry() *time.Duration
// Resumable returns whether or not the job is resumable
Resumable() bool
// LocalPresets returns the preset options of a job
LocalPresets() *PresetInfo
}
JobImpl provides the definition for any job that can be executed on splashtail
Click to show internal directories.
Click to hide internal directories.