rpc_messages

package
v0.0.0-...-792b534 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 27, 2025 License: AGPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Spawn

type Spawn struct {
	Name    string                 `json:"name"`
	Data    map[string]interface{} `json:"data"`
	Create  bool                   `json:"create"`
	Execute bool                   `json:"execute"`

	// If create is false, then task id must be set
	ID string `json:"id"`

	// The Guild ID which initiated the action
	GuildID string `json:"guild_id"`
}

Spawns a job and executes it if the execute argument is set.

type SpawnResponse

type SpawnResponse struct {
	ID string `json:"id"`
}

Jump to