Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func ExecuteJobLocal ¶
func ExecuteJobLocal(prefix, id string, l *zap.Logger, jobImpl interfaces.JobImpl, opts TaskLocalOpts, state jobstate.State) error
Executes a job locally
func OpenDefault ¶
From https://github.com/icza/gox/blob/master/osx/osx.go
OpenDefault opens the specified file or URL with the default associated application.
You may use it to open a web site:
OpenDefault("https://google.com")
Or open a file:
OpenDefault("/home/bob/story.txt")
Or open a folder in your default file manager:
OpenDefault("/home/bob")
For details, see https://stackoverflow.com/a/39324149/1705598
func UserInputBoolean ¶
Types ¶
type LocalMutLogger ¶
func NewLocalLogger ¶
func (*LocalMutLogger) Sync ¶
func (m *LocalMutLogger) Sync() error
type State ¶
type State struct {
GuildId string
DiscordSess *discordgo.Session
BotUser *discordgo.User
DebugInfoData *debug.BuildInfo
ContextUse context.Context
}
Implementor of jobstate.State
func (State) OperationMode ¶
type TaskLocalOpts ¶
Click to show internal directories.
Click to hide internal directories.