Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Spawn ¶
type Spawn struct {
Name string `json:"name"`
Data map[string]interface{} `json:"data"`
Create bool `json:"create"`
Execute bool `json:"execute"`
// If create is false, then task id must be set
ID string `json:"id"`
// The Guild ID which initiated the action
GuildID string `json:"guild_id"`
}
Spawns a job and executes it if the execute argument is set.
type SpawnResponse ¶
type SpawnResponse struct {
ID string `json:"id"`
}
Click to show internal directories.
Click to hide internal directories.